Learn R Programming

DataSetsUni (version 0.1)

Somalia COVID-19: COVID-19 mortality rates in Somalia

Description

The function allows to provide the COVID-19 mortality rate in Somalia during the time between 1 st March 2021 to 20 th April 2021, with a total of 51 observed values.

Usage

data_RateMor

Value

data_RateMor gives the COVID-19 mortality rate from Somalia.

Arguments

data_RateMor

A vector of (non-negative integer) values.

Author

Muhammad Imran.

R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com.

Details

The data set contains the COVID-19 mortality rate from Somalia during the time between 1 st March 2021 to 20 th April 2021, with a total of 51 observed values. Recently, it is used by Muse et al. (2021) and fitted a new versatile modification of the log-logistic distribution.

References

Muse, A. H., Tolba, A. H., Fayad, E., Abu Ali, O. A., Nagy, M., & Yusuf, M. (2021). Modelling the COVID-19 mortality rate with a new versatile modification of the log-logistic distribution. Computational Intelligence and Neuroscience, 2021.

See Also

data_COVIDDeath, data_COVID19MH, data_COVIDmor

Examples

Run this code
x<-data_RateMor
summary(x)

Run the code above in your browser using DataLab