Learn R Programming

DataSetsUni (version 0.1)

Wind Catastrophes Losses: The losses due to wind catastrophes recorded in 1977

Description

The function allows to provide the losses due to wind catastrophes recorded in 1977.

Usage

data_Losses

Value

data_Losses gives the losses due to wind catastrophes recorded in 1977.

Arguments

data_Losses

A vector of (non-negative integer) values.

Author

Muhammad Imran.

R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com.

Details

The data set represents the losses due to wind catastrophes recorded in 1977. Recently, it is used by Ijaz and Asim (2019) and fitted the odd Burr-III Lomax distribution.

References

Ijaz, M., & Asim, S. M. (2019). Lomax exponential distribution with an application to real-life data. PloS one, 14(12), e0225827.

Ihtisham, S., Khalil, A., Manzoor, S., Khan, S. A., & Ali, A. (2019). Alpha-Power Pareto distribution: Its properties and applications. PloS one, 14(6), e0218027.

Hogg, R. V. (1984). S. A. Klugman, Loss Distributions. New York Wiley, 569-574.

See Also

data_vehicleinsur

Examples

Run this code
x<-data_Losses
summary(x)

Run the code above in your browser using DataLab